Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorUwe Stieber2013-09-09 06:23:46 +0000
committerUwe Stieber2013-09-09 07:26:49 +0000
commit16c957d1f5960de7040f8ce9482e4c86e29ab045 (patch)
tree8f4d27befdc44426fedd419624ca2413b975fcad /target_explorer/plugins/org.eclipse.tcf.te.tcf.core
parentd9480f0083ddeb1fd8d67d510ae3d00ae9cbae3b (diff)
downloadorg.eclipse.tcf-16c957d1f5960de7040f8ce9482e4c86e29ab045.tar.gz
org.eclipse.tcf-16c957d1f5960de7040f8ce9482e4c86e29ab045.tar.xz
org.eclipse.tcf-16c957d1f5960de7040f8ce9482e4c86e29ab045.zip
Target Explorer: Complete path map service API by adding removePathMap
Diffstat (limited to 'target_explorer/plugins/org.eclipse.tcf.te.tcf.core')
-rw-r--r--target_explorer/plugins/org.eclipse.tcf.te.tcf.core/src/org/eclipse/tcf/te/tcf/core/interfaces/IPathMapService.java16
1 files changed, 15 insertions, 1 deletions
diff --git a/target_explorer/plugins/org.eclipse.tcf.te.tcf.core/src/org/eclipse/tcf/te/tcf/core/interfaces/IPathMapService.java b/target_explorer/plugins/org.eclipse.tcf.te.tcf.core/src/org/eclipse/tcf/te/tcf/core/interfaces/IPathMapService.java
index a59d77cb9..21a902795 100644
--- a/target_explorer/plugins/org.eclipse.tcf.te.tcf.core/src/org/eclipse/tcf/te/tcf/core/interfaces/IPathMapService.java
+++ b/target_explorer/plugins/org.eclipse.tcf.te.tcf.core/src/org/eclipse/tcf/te/tcf/core/interfaces/IPathMapService.java
@@ -16,7 +16,8 @@ import org.eclipse.tcf.te.runtime.services.interfaces.IService;
/**
* Path map service.
* <p>
* Allow the access to the configured path maps for a given context.
*/
public interface IPathMapService extends IService {
@@ -51,6 +52,19 @@ public interface IPathMapService extends IService {
public IPathMap.PathMapRule addPathMap(Object context, String source, String destination);
/**
+ * Removes the given path mapping rule from the configured (object) path mappings
+ * for the given context.
+ * <p>
+ * The method auto applies the new path map to an possibly open shared channel.
+ * <p>
+ * <b>Note:</b> This method must be called from outside the TCF event dispatch thread.
+ *
+ * @param context The context. Must not be <code>null</code>.
+ * @param rule The path map rule. Must not be <code>null</code>.
+ */
+ public void removePathMap(Object context, IPathMap.PathMapRule rule);
+
+ /**
* Apply the configured (object) path mappings to the given context.
* <p>
* <b>Note:</b> This method must be called from outside the TCF event dispatch thread.
@@ -16,7 +16,8 @@ import org.eclipse.tcf.te.runtime.services.interfaces.IService;
* Path map service.
* <p>
- * Allow the access to the configured path maps for a given context.
+ * Allow the access and manipulation of the configured (object) path maps
+ * for a given context.
*/
public interface IPathMapService extends IService {

Back to the top